@@ -134,6 +134,13 @@ class EvaluationJobConfig(proto.Message):
     job works. Provide this configuration when you create an
     EvaluationJob.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         image_classification_config (google.cloud.datalabeling_v1beta1.types.ImageClassificationConfig):
             Specify this field if your model version performs image
@@ -144,12 +151,14 @@ class EvaluationJobConfig(proto.Message):
             ``allowMultiLabel`` in this configuration must match
             ``classificationMetadata.isMultiLabel`` in
             [input_config][google.cloud.datalabeling.v1beta1.EvaluationJobConfig.input_config].
+            This field is a member of `oneof`_ ``human_annotation_request_config``.
         bounding_poly_config (google.cloud.datalabeling_v1beta1.types.BoundingPolyConfig):
             Specify this field if your model version performs image
             object detection (bounding box detection).
 
             ``annotationSpecSet`` in this configuration must match
             [EvaluationJob.annotationSpecSet][google.cloud.datalabeling.v1beta1.EvaluationJob.annotation_spec_set].
+            This field is a member of `oneof`_ ``human_annotation_request_config``.
         text_classification_config (google.cloud.datalabeling_v1beta1.types.TextClassificationConfig):
             Specify this field if your model version performs text
             classification.
@@ -159,6 +168,7 @@ class EvaluationJobConfig(proto.Message):
             ``allowMultiLabel`` in this configuration must match
             ``classificationMetadata.isMultiLabel`` in
             [input_config][google.cloud.datalabeling.v1beta1.EvaluationJobConfig.input_config].
+            This field is a member of `oneof`_ ``human_annotation_request_config``.
         input_config (google.cloud.datalabeling_v1beta1.types.InputConfig):
             Rquired. Details for the sampled prediction input. Within
             this configuration, there are requirements for several
